@@ -3,7 +3,7 @@ import ReactDOM from "react-dom";
 import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
 import { getDefaultConfig, RainbowKitProvider } from "@rainbow-me/rainbowkit";
 import { WagmiProvider } from "wagmi";
-import { Chain, gnosis, localhost } from "wagmi/chains";
+import { gnosis } from "wagmi/chains";
 import PythonWeb3Wallet from "./PythonWeb3Wallet";
 
 const queryClient = new QueryClient();
@@ -18,6 +18,8 @@ const queryClient = new QueryClient();
 //   },
 // } as const satisfies Chain;
 
+console.log('debug', process.env.REACT_APP_DEBUG_VARIABLE);
+
 const config = getDefaultConfig({
   appName: 'app',
   projectId: process.env.REACT_APP_RAINBOW_PROJECT_ID!,
